@@ -115,6 +115,8 @@ sub paymentaccounts {
   }
   $sth->finish;
 
+  $form->get_peripherals($dbh);
+
   $dbh->disconnect if $disconnect;
 
 }
@@ -186,8 +188,6 @@ sub get_openvc {
     }
   }
 
-  my $buysell = ($arap eq 'ar') ? 'buy' : 'sell';
-
   my $sortorder = "name";
   if ($defaults{namesbynumber}) {
     $sortorder = "$form->{vc}number";
@@ -273,8 +273,6 @@ sub retrieve {
 
   my $ml = 1;
   
-  $form->{id} *= 1;
-
   if ($form->{vc} eq 'customer') {
     $ml = -1;
   }
@@ -396,7 +394,7 @@ sub retrieve {
   ($form->{batchdescription}, $form->{vouchernumber}) = $dbh->selectrow_array($query);
     
   $form->{voucherid} = $form->{id};
-  $form->{id} = 1;
+  $form->{id} = "1";
   AA->get_name($myconfig, $form, $dbh);
 
   $form->{"old$form->{vc}"} = qq|$form->{$form->{vc}}--$form->{"$form->{vc}_id"}|;
@@ -476,8 +474,6 @@ sub get_openinvoices {
   }
   
   my $datepaid = ($form->{datepaid}) ? "date '$form->{datepaid}'" : 'current_date';
-  my $buysell = ($form->{arap} eq 'ar') ? 'buy' : 'sell';
-  
   my $query = qq|SELECT DISTINCT a.id, a.invnumber, a.transdate, a.duedate,
                  a.description AS invdescription,
 		 a.amount, a.paid, a.curr, vc.$form->{vc}number, vc.name,
@@ -486,7 +482,7 @@ sub get_openinvoices {
 		 a.$form->{vc}_id,
 		 a.discountterms, a.cashdiscount, a.netamount,
 		 $datepaid <= a.transdate + a.discountterms AS calcdiscount,
-		 a.exchangerate, ex.$buysell AS vcexch,
+		 a.exchangerate, ex.exchangerate AS vcexch,
 		 a.taxincluded
 		 FROM acc_trans ac
 		 JOIN $form->{arap} a ON (a.id = ac.trans_id)
@@ -564,11 +560,7 @@ sub post_payment {
   if ($form->{currency} ne $form->{defaultcurrency}) {
     $form->{exchangerate} = $form->parse_amount($myconfig, $form->{exchangerate});
 
-    if ($form->{vc} eq 'customer') {
-      $form->update_exchangerate($dbh, $form->{currency}, $form->{datepaid}, $form->{exchangerate}, 0);
-    } else {
-      $form->update_exchangerate($dbh, $form->{currency}, $form->{datepaid}, 0, $form->{exchangerate});
-    }
+    $form->update_exchangerate($dbh, $form->{currency}, $form->{datepaid}, $form->{exchangerate});
   } else {
     $form->{exchangerate} = 1;
   }
@@ -589,8 +581,6 @@ sub post_payment {
   
   my %defaults = $form->get_defaults($dbh, \@{['fx%_accno_id', 'cdt']});
 
-  my $buysell = ($form->{vc} eq 'customer') ? 'buy' : 'sell';
-  
   my $ml;
   my $where;
   
@@ -641,7 +631,6 @@ sub post_payment {
   my $rate;
 
   # delete payments
-  $form->{voucherid} *= 1;
   if ($form->{edit} && $form->{voucherid}) {
     $query = qq|SELECT SUM(ac.amount) * $ml * -1
                 FROM acc_trans ac
@@ -830,6 +819,7 @@ sub post_payment {
 		    $voucherid)|;
 	$dbh->do($query) || $form->dberror($query);
       }
+
       
       # deduct tax for cash discount
       if ($form->{"discount_$i"}) {
