@@ -941,10 +941,9 @@ sub post_invoice {
       my $decimalplaces = ($dec > $form->{precision}) ? $dec : $form->{precision};
       
       # undo discount formatting
-      my $discount = $form->{"discount_$i"};
       $form->{"discount_$i"} = $form->parse_amount($myconfig, $form->{"discount_$i"})/100;
       
-      $discount = $form->round_amount($fxsellprice * $discount/100, $decimalplaces);
+      my $discount = $form->round_amount($fxsellprice * $form->{"discount_$i"}, $decimalplaces);
       
       # deduct discount
       $form->{"sellprice_$i"} = $fxsellprice - $discount;
