@@ -103,7 +103,7 @@ sub create_links {
   $form->all_projects($myconfig, $dbh);
 
   $form->all_languages($myconfig, $dbh);
-  
+
   $dbh->disconnect;
 
 }
@@ -131,7 +131,7 @@ sub income_statement {
     my $transdate = $form->{todate};
     $transdate ||= $form->current_date($myconfig);
  
-    $form->{exchangerate} = $form->get_exchangerate($myconfig, $dbh, $form->{currency}, $transdate, 'buy');
+    $form->{exchangerate} = $form->get_exchangerate($myconfig, $dbh, $form->{currency}, $transdate);
   }
     
   $form->{exchangerate} ||= 1;
@@ -153,7 +153,9 @@ sub income_statement {
 
   my %defaults = $form->get_defaults($dbh, \@{['company','address','businessnumber']});
   for (keys %defaults) { $form->{$_} = $defaults{$_} }
-  
+
+  $form->report_level($myconfig, $dbh);
+
   # disconnect
   $dbh->disconnect;
 
@@ -255,7 +257,6 @@ sub income_statement {
 
   }
 
-
   $form->{total_income_this_period} = $form->format_amount($myconfig,$form->{total_income_this_period}, $form->{decimalplaces}, "- ");
   $form->{total_expenses_this_period} = $form->format_amount($myconfig,$form->{total_expenses_this_period}, $form->{decimalplaces}, "- ");
   $form->{total_this_period} = $form->format_amount($myconfig,$form->{total_this_period}, $form->{decimalplaces}, "- ");
@@ -300,7 +301,7 @@ sub balance_sheet {
     my $transdate = $form->{asofdate};
     $transdate ||= $form->current_date($myconfig);
  
-    $form->{exchangerate} = $form->get_exchangerate($myconfig, $dbh, $form->{currency}, $transdate, 'buy');
+    $form->{exchangerate} = $form->get_exchangerate($myconfig, $dbh, $form->{currency}, $transdate);
   }
     
   $form->{exchangerate} ||= 1;
@@ -332,6 +333,8 @@ sub balance_sheet {
   my %defaults = $form->get_defaults($dbh, \@{['company','address','businessnumber']});
   for (keys %defaults) { $form->{$_} = $defaults{$_} }
   
+  $form->report_level($myconfig, $dbh);
+
   # disconnect
   $dbh->disconnect;
 
@@ -1347,6 +1350,10 @@ sub trial_balance {
     
   }
 
+  $form->retrieve_report($myconfig, $dbh);
+
+  $form->report_level($myconfig, $dbh);
+
   $dbh->disconnect;
 
   # debits and credits for headings
@@ -1374,8 +1381,14 @@ sub aging {
   my $item;
   my $curr;
   
-  my %defaults = $form->get_defaults($dbh, \@{[qw(company address businessnumber tel fax precision)]});
+  my @df = qw(company address businessnumber tel fax precision);
+  my %defaults = $form->get_defaults($dbh, \@df);
   for (keys %defaults) { $form->{$_} = $defaults{$_} }
+  
+  $form->get_peripherals($dbh);
+  for (@{ $form->{all_printer} }) {
+    $form->{"$_->{printer}_printer"} = $_->{command};
+  }
 
   $form->{currencies} = $form->get_currencies($dbh, $myconfig);
   
@@ -1392,15 +1405,15 @@ sub aging {
   my $transdate = ($form->{overdue}) ? "duedate" : "transdate";
 
   if ($form->{"$form->{vc}_id"}) {
-    $where .= qq| AND ct.id = $form->{"$form->{vc}_id"}|;
+    $where .= qq| AND vc.id = $form->{"$form->{vc}_id"}|;
   } else {
     if ($form->{$form->{vc}} ne "") {
       $name = $form->like(lc $form->{$form->{vc}});
-      $where .= qq| AND lower(ct.name) LIKE '$name'|;
+      $where .= qq| AND lower(vc.name) LIKE '$name'|;
     }
     if ($form->{"$form->{vc}number"} ne "") {
       $name = $form->like(lc $form->{"$form->{vc}number"});
-      $where .= qq| AND lower(ct.$form->{vc}number) LIKE '$name'|;
+      $where .= qq| AND lower(vc.$form->{vc}number) LIKE '$name'|;
     }
   }
 
@@ -1410,13 +1423,13 @@ sub aging {
   }
   
   $form->{sort} =~ s/;//g;
-  my $sortorder = ($form->{sort}) ? "ct.$form->{sort}" : "ct.name";
+  my $sortorder = ($form->{sort}) ? "vc.$form->{sort}" : "vc.name";
   
-  # select outstanding vendors or customers, depends on $ct
-  $query = qq|SELECT DISTINCT ct.id, ct.name, ct.$form->{vc}number,
-              ct.language_code
-              FROM $form->{vc} ct
-	      JOIN $form->{arap} a ON (a.$form->{vc}_id = ct.id)
+  # select outstanding vendors or customers
+  $query = qq|SELECT DISTINCT vc.id, vc.name, vc.$form->{vc}number,
+              vc.language_code
+              FROM $form->{vc} vc
+	      JOIN $form->{arap} a ON (a.$form->{vc}_id = vc.id)
 	      WHERE $where
               AND a.paid != a.amount
               AND (a.$transdate <= '$form->{todate}')
@@ -1430,8 +1443,6 @@ sub aging {
   }
   $sth->finish;
 
-  my $buysell = ($form->{arap} eq 'ar') ? 'buy' : 'sell';
-  
   my %interval = ( 'Pg' => {
                         'c0' => "(date '$form->{todate}' - interval '0 days')",
 			'c15' => "(date '$form->{todate}' - interval '15 days')",
@@ -1465,6 +1476,8 @@ sub aging {
     $where .= qq| AND a.department_id = $department_id|;
   }
 
+  $form->{AG} = ();
+
   $query = "";
   my $union = "";
 
@@ -1485,96 +1498,91 @@ sub aging {
     }
   }
 
-  $item = $#c;
-  $c{$c[$item]}{and} = qq|AND a.$transdate < $interval{$myconfig->{dbdriver}}{$c[$item]}|;
-
-  if ($item > 0) {
-    $c{$c[0]}{and} = qq|
-    	  AND (
-		  a.$transdate <= $interval{$myconfig->{dbdriver}}{$c[0]}
-		  AND a.$transdate >= $interval{$myconfig->{dbdriver}}{$c[1]}
- 	      )|;
-  }
- 
-  for (1 .. $item - 1) {
-    $c{$c[$_]}{and} = qq|
-    	  AND (
-		  a.$transdate < $interval{$myconfig->{dbdriver}}{$c[$_]}
-		  AND a.$transdate >= $interval{$myconfig->{dbdriver}}{$c[$_+1]}
- 	      )|;
-  }
-
-  for (@c) {
+  if (@c) {
     
-    $query .= qq|$union
-    SELECT c.id AS vc_id, c.$form->{vc}number, c.name,
-    ad.address1, ad.address2, ad.city, ad.state, ad.zipcode, ad.country,
-    c.contact, c.email,
-    c.phone as $form->{vc}phone, c.fax as $form->{vc}fax,
-    c.$form->{vc}number, c.taxnumber as $form->{vc}taxnumber,
-    a.description AS invdescription,
-    a.invnumber, a.transdate, a.till, a.ordnumber, a.ponumber, a.notes,
-    $c{$_}{flds},
-    a.duedate, a.invoice, a.id, a.curr,
-      (SELECT $buysell FROM exchangerate e
-       WHERE a.curr = e.curr
-       AND e.transdate = a.transdate) AS exchangerate,
-    ct.firstname, ct.lastname, ct.salutation, ct.typeofcontact,
-    s.*
-    FROM $form->{arap} a
-    JOIN $form->{vc} c ON (a.$form->{vc}_id = c.id)
-    JOIN address ad ON (ad.trans_id = c.id)
-    LEFT JOIN contact ct ON (ct.trans_id = c.id)
-    LEFT JOIN shipto s ON (a.id = s.trans_id)
-    WHERE $where
-    $c{$_}{and}
-|;
+    $item = $#c;
+    $c{$c[$item]}{and} = qq|AND a.$transdate < $interval{$myconfig->{dbdriver}}{$c[$item]}|;
 
-    $union = qq|
-    UNION
-|;
-  }
-	  
-  $query .= qq|
+    if ($item > 0) {
+      $c{$c[0]}{and} = qq|
+	    AND (
+		    a.$transdate <= $interval{$myconfig->{dbdriver}}{$c[0]}
+		    AND a.$transdate >= $interval{$myconfig->{dbdriver}}{$c[1]}
+		)|;
+    }
+   
+    for (1 .. $item - 1) {
+      $c{$c[$_]}{and} = qq|
+	    AND (
+		    a.$transdate < $interval{$myconfig->{dbdriver}}{$c[$_]}
+		    AND a.$transdate >= $interval{$myconfig->{dbdriver}}{$c[$_+1]}
+		)|;
+    }
 
-      ORDER BY vc_id, $transdate, invnumber|;
-
-  $sth = $dbh->prepare($query) || $form->dberror($query);
-
-  my @var;
-  
-  foreach $curr (split /:/, $form->{currencies}) {
-  
-    foreach $item (@ot) {
-
-      @var = ();
-      for (@c) { push @var, ($item->{id}, $curr) }
+    for (@c) {
       
-      $sth->execute(@var);
+      $query .= qq|$union
+      SELECT c.id AS vc_id, c.$form->{vc}number, c.name,
+      ad.address1, ad.address2, ad.city, ad.state, ad.zipcode, ad.country,
+      c.contact, c.email,
+      c.phone as $form->{vc}phone, c.fax as $form->{vc}fax,
+      c.$form->{vc}number, c.taxnumber as $form->{vc}taxnumber,
+      a.description AS invdescription,
+      a.invnumber, a.transdate, a.till, a.ordnumber, a.ponumber, a.notes,
+      $c{$_}{flds},
+      a.duedate, a.invoice, a.id, a.curr,
+	(SELECT exchangerate FROM exchangerate e
+	 WHERE a.curr = e.curr
+	 AND e.transdate = a.transdate) AS exchangerate,
+      ct.firstname, ct.lastname, ct.salutation, ct.typeofcontact,
+      s.*
+      FROM $form->{arap} a
+      JOIN $form->{vc} c ON (a.$form->{vc}_id = c.id)
+      JOIN address ad ON (ad.trans_id = c.id)
+      LEFT JOIN contact ct ON (ct.trans_id = c.id)
+      LEFT JOIN shipto s ON (a.id = s.trans_id)
+      WHERE $where
+      $c{$_}{and}
+|;
+
+      $union = qq|
+      UNION
+|;
+    }
+	    
+    $query .= qq|
+	ORDER BY vc_id, $transdate, invnumber|;
+
+    $sth = $dbh->prepare($query) || $form->dberror($query);
+
+    my @var;
+    my $i;
+    
+    foreach $curr (split /:/, $form->{currencies}) {
+    
+      foreach $item (@ot) {
+
+	@var = ();
+	for (@c) { push @var, ($item->{id}, $curr) }
+	
+	$sth->execute(@var);
+
+	while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
+	  $ref->{module} = ($ref->{invoice}) ? $invoice : $form->{arap};
+	  $ref->{module} = 'ps' if $ref->{till};
+	  $ref->{exchangerate} ||= 1;
+	  $ref->{language_code} = $item->{language_code};
+
+	  push @{ $form->{AG} }, $ref;
+	}
+	$sth->finish;
 
-      while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
-	$ref->{module} = ($ref->{invoice}) ? $invoice : $form->{arap};
-	$ref->{module} = 'ps' if $ref->{till};
-	$ref->{exchangerate} ||= 1;
-	$ref->{language_code} = $item->{language_code};
-	push @{ $form->{AG} }, $ref;
       }
-      $sth->finish;
-
     }
   }
 
   # get language
-  my $query = qq|SELECT *
-                 FROM language
-		 ORDER BY 2|;
-  $sth = $dbh->prepare($query);
-  $sth->execute || $form->dberror($query);
-
-  while ($ref = $sth->fetchrow_hashref(NAME_lc)) { 
-    push @{ $form->{all_language} }, $ref;
-  }
-  $sth->finish;
+  $form->all_languages($myconfig, $dbh);
 
   # disconnect
   $dbh->disconnect;
@@ -1592,20 +1600,28 @@ sub reminder {
 
   my $item;
   my $curr;
-
-  my @a = qw(company companyemail companywebsite address businessnumber tel fax precision);
-  my %defaults = $form->get_defaults($dbh, \@a);
+  
+  my @df = qw(company companyemail companywebsite address businessnumber tel fax precision);
+  my %defaults = $form->get_defaults($dbh, \@df);
   for (keys %defaults) { $form->{$_} = $defaults{$_} }
   
+  $form->get_peripherals($dbh);
+  for (@{ $form->{all_printer} }) {
+    $form->{"$_->{printer}_printer"} = $_->{command};
+  }
+
   $form->{currencies} = $form->get_currencies($dbh, $myconfig);
   
   my $where = "a.approved = '1'";
   my $name;
   my $null;
+  my $vc_id;
   my $ref;
 
-  if ($form->{"$form->{vc}_id"}) {
-    $where .= qq| AND vc.id = $form->{"$form->{vc}_id"}|;
+  ($null, $vc_id) = split /--/, $form->{$form->{vc}};
+      
+  if ($vc_id) {
+    $where .= qq| AND vc.id = $vc_id|;
   } else {
     if ($form->{$form->{vc}} ne "") {
       $name = $form->like(lc $form->{$form->{vc}});
@@ -1670,7 +1686,7 @@ sub reminder {
 	      c.contact, c.email,
 	      c.phone as $form->{vc}phone, c.fax as $form->{vc}fax,
 	      c.$form->{vc}number, c.taxnumber as $form->{vc}taxnumber,
-	      a.description AS invdescription,
+	      a.dcn, a.bank_id, a.description AS invdescription,
 	      a.invnumber, a.transdate, a.till, a.ordnumber, a.ponumber, a.notes,
 	      a.amount - a.paid AS due,
 	      a.duedate, a.invoice, a.id, a.curr,
@@ -1689,6 +1705,11 @@ sub reminder {
 	      ORDER BY vc_id, transdate, invnumber|;
   $sth = $dbh->prepare($query) || $form->dberror($query);
 
+  $query = qq|SELECT rvc
+              FROM bank
+	      WHERE id = ?|;
+  my $bth = $dbh->prepare($query) || $form->dberror($query);
+  
   $form->{AG} = ();
   
   for $curr (split /:/, $form->{currencies}) {
@@ -1703,6 +1724,10 @@ sub reminder {
 	$ref->{exchangerate} ||= 1;
 	$ref->{language_code} = $item->{language_code};
 
+	$bth->execute($ref->{bank_id});
+	($ref->{rvc}) = $bth->fetchrow_array;
+	$bth->finish;
+
 	$rth->execute($ref->{id}, $curr);
 	$found = 0;
 	while (($reminder) = $rth->fetchrow_array) {
@@ -1781,7 +1806,7 @@ sub get_customer {
                  FROM $form->{vc} ct
 		 WHERE ct.id = $form->{"$form->{vc}_id"}|;
   ($form->{$form->{vc}}, $form->{email}, $form->{cc}, $form->{bcc}) = $dbh->selectrow_array($query);
-  
+
   $dbh->disconnect;
 
 }
@@ -1927,8 +1952,8 @@ sub tax_report {
 		  'description' => 8
 		);
   
-  my @a = qw(transdate invnumber name);
-  my $sortorder = $form->sort_order(\@a, \%ordinal);
+  my @sf = qw(transdate invnumber name);
+  my $sortorder = $form->sort_order(\@sf, \%ordinal);
 
   if ($form->{summary}) {
     
@@ -2058,7 +2083,7 @@ sub tax_report {
     }
 
 
-  if ($form->{report} =~ /nontaxable/) {
+  if ($form->{reportcode} =~ /nontaxable/) {
 
     if ($form->{summary}) {
       # only gather up non-taxable transactions
@@ -2198,7 +2223,7 @@ sub tax_report {
 
   while ( my $ref = $sth->fetchrow_hashref(NAME_lc)) {
     $ref->{tax} = $form->round_amount($ref->{tax}, $form->{precision});
-    if ($form->{report} =~ /nontaxable/) {
+    if ($form->{reportcode} =~ /nontaxable/) {
       push @{ $form->{TR} }, $ref if $ref->{netamount};
     } else {
       push @{ $form->{TR} }, $ref if $ref->{tax};
@@ -2317,8 +2342,8 @@ sub payments {
 		  'reference' => 15
 		);
 
-  my @a = qw(name transdate employee);
-  my $sortorder = $form->sort_order(\@a, \%ordinal);
+  my @sf = qw(name transdate employee);
+  my $sortorder = $form->sort_order(\@sf, \%ordinal);
   
   # cycle through each id
   foreach my $accno (split(/ /, $form->{paymentaccounts})) {
@@ -2353,10 +2378,6 @@ sub payments {
     if ($form->{till} ne "") {
       $query .= " AND a.invoice = '1' 
                   AND NOT a.till IS NULL";
-      
-      if ($myconfig->{role} eq 'user') {
-	$query .= " AND e.login = '$form->{login}'";
-      }
     }
 
     $query .= qq|
