@@ -23,7 +23,7 @@ sub create_links {
   $form->all_employees($myconfig, $dbh, undef, 0);
 
   $form->remove_locks($myconfig, $dbh, 'br');
-  
+
   $dbh->disconnect;
   
 }
@@ -84,10 +84,9 @@ sub list_batches {
  
   my $query = qq|SELECT a.id, a.batch, a.batchnumber, a.description,
                  a.transdate, a.apprdate, a.amount,
-		 e.name AS employee, m.name AS manager
+		 e.name AS employee
 	         FROM br a
 	      LEFT JOIN employee e ON (a.employee_id = e.id)
-	      LEFT JOIN employee m ON (a.managerid = m.id)
 	      |;
 
   my %ordinal = ( id => 1,
@@ -95,27 +94,20 @@ sub list_batches {
 		  description => 3,
 		  transdate => 4,
 		  apprdate => 5,
-		  employee => 7,
-		  manager => 8
+		  employee => 7
 		);
 
   
-  my @a = (batchnumber, transdate, apprdate);
-  push @a, "employee" if $form->{l_employee};
-  push @a, "manager" if $form->{l_manager};
-  my $sortorder = $form->sort_order(\@a, \%ordinal);
+  my @sf = (batchnumber, transdate, apprdate);
+  push @sf, "employee" if $form->{l_employee};
+  my $sortorder = $form->sort_order(\@sf, \%ordinal);
 
   my $where = "1 = 1";
   $where .= " AND a.batch = '$form->{batch}'" if $form->{batch};
 
-  if ($myconfig->{role} eq 'user') {
-    ($null, $var) = $form->get_employee($dbh);
+  if ($form->{employee}) {
+    ($null, $var) = split /--/, $form->{employee};
     $where .= " AND a.employee_id = $var";
-  } else {
-    if ($form->{employee}) {
-      ($null, $var) = split /--/, $form->{employee};
-      $where .= " AND a.employee_id = $var";
-    }
   }
 
   if ($form->{batchnumber}) {
@@ -146,6 +138,7 @@ sub list_batches {
   }
   
   $sth->finish;
+
   $dbh->disconnect;
 
 }
@@ -183,7 +176,7 @@ sub post_transaction {
 		WHERE id = $form->{batchid}|;
     $dbh->do($query) || $form->dberror($query);
 
-    if (!($rc = $dbh->commit)) {
+    if(!($rc = $dbh->commit)) {
       $dbh->disconnect;
       return;
     }
@@ -230,8 +223,8 @@ sub list_vouchers {
 		  vouchernumber => 6
 		);
 
-  my @a = (vouchernumber);
-  my $sortorder = $form->sort_order(\@a, \%ordinal);
+  my @sf = (vouchernumber);
+  my $sortorder = $form->sort_order(\@sf, \%ordinal);
 
   if ($form->{batch} eq 'ap') {
     
@@ -304,8 +297,8 @@ sub list_vouchers {
   while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
     push @{ $form->{transactions} }, $ref;
   }
-  
   $sth->finish;
+
   $dbh->disconnect;
 
 }
@@ -320,8 +313,6 @@ sub delete_transaction {
   
   my $table = "ap";
   $table = "gl" if $form->{batch} eq 'gl';
-
-  $form->{id} *= 1;
   
   $query = qq|SELECT amount
               FROM $table
@@ -366,9 +357,7 @@ sub delete_payment_reversal {
   # connect to database
   my $dbh = $form->dbconnect_noauto($myconfig);
   my $query;
-
-  $form->{id} *= 1;
-  
+ 
   $query = qq|SELECT ac.trans_id, ac.amount * -1
               FROM acc_trans ac
 	      JOIN vr ON (vr.id = ac.vr_id)
@@ -421,9 +410,7 @@ sub delete_batch {
 
   # connect to database
   my $dbh = $form->dbconnect_noauto($myconfig);
-
-  $form->{batchid} *= 1;
-    
+  
   my $query = qq|SELECT vr.id, vr.trans_id
                  FROM vr
 	         WHERE vr.br_id = $form->{batchid}|;
@@ -531,8 +518,6 @@ sub post_batch {
     $disconnect = 1;
   }
 
-  $form->{batchid} *= 1;
-  
   my $query = qq|SELECT trans_id, id
                  FROM vr
 	         WHERE br_id = $form->{batchid}|;
@@ -603,7 +588,9 @@ sub post_batch {
   
   my $rc = $dbh->commit;
     
-  $dbh->disconnect if $disconnect;
+  if ($disconnect) {
+    $dbh->disconnect;
+  }
 
   $rc;
 
@@ -638,7 +625,7 @@ sub payment_reversal {
   my $description;
   my $translation;
 
-  if ($form->{id} *= 1) {
+  if ($form->{id}) {
     # get payment account and vouchernumber
     $query = qq|SELECT ac.source, ac.memo, c.accno, c.description,
                 l.description
@@ -669,9 +656,7 @@ sub post_payment_reversal {
   
   $form->{vouchernumber} = $form->update_defaults($myconfig, 'vouchernumber', $dbh) unless $form->{vouchernumber};
   
-  $form->{batchid} *= 1;
-  
-  if ($form->{id} *= 1) {
+  if ($form->{id}) {
 
     $query = qq|SELECT ac.amount
 		FROM acc_trans ac
@@ -767,10 +752,10 @@ sub post_payment_reversal {
     
     # get AP account
     $ath->execute($ref->{trans_id});
-    my ($ap_id) = $ath->fetchrow_array;
+    my ($apid) = $ath->fetchrow_array;
     $ath->finish;
     
-    if ($ap_id) {
+    if ($apid) {
     
       # create voucher
       $vth->execute($ref->{trans_id});
@@ -781,7 +766,7 @@ sub post_payment_reversal {
       $pth->finish;
       
       # post offsetting AP
-      $pth->execute($ref->{trans_id}, $ap_id, $ref->{amount}, $ref->{fx_transaction});
+      $pth->execute($ref->{trans_id}, $apid, $ref->{amount}, $ref->{fx_transaction});
       $pth->finish;
 
       # update balance for batch
