@@ -816,7 +816,7 @@ sub form_header {
 
   $column_data{datepaid} = "<th nowrap>".$locale->text('Date')."</th>";
   $column_data{paid} = "<th>".$locale->text('Amount')."</th>";
-  $column_data{exchangerate} = "<th>".$locale->text('Exch')." <font color=red>*</font></th>";
+  $column_data{exchangerate} = "<th>".$locale->text('Exch')."</th>";
   $column_data{ARAP_paid} = "<th>".$locale->text('Account')."</th>";
   $column_data{source} = "<th>".$locale->text('Source')."</th>";
   $column_data{memo} = "<th>".$locale->text('Memo')."</th>";
@@ -1094,20 +1094,19 @@ sub form_footer {
 	for ("Post", "Print and Post", "Delete") { delete $button{$_} }
       }
 	
-      if (!$latex) {
-	for ("Preview", "Print and Post", "Print and Post as new") { delete $button{$_} }
-      }
-
     } else {
       
       for ("Post as new", "Print and Post as new", "Delete") { delete $button{$_} }
-      delete $button{"Print and Post"} if ! $latex;
       
       if ($transdate <= $form->{closedto}) {
 	for ("Post", "Print and Post") { delete $button{$_} }
       }
     }
 
+    if (!$latex) {
+      for ("Preview", "Print and Post", "Print and Post as new") { delete $button{$_} }
+    }
+
     for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
     
   }
