@@ -450,12 +450,15 @@ sub prepare_employee {
 
       while (@member) {
 	$_ = shift @member;
-	next if ! /\[$form->{employeelogin}(\@|\])??/;
+	next if ! /\[$form->{employeelogin}\@$myconfig{dbname}\]/;
 	do {
+          if (/pin/) {
+            chomp;
+            ($null, $form->{pin}) = split /=/, $_, 2;
+          }
 	  if (/password/) {
+            chomp;
 	    ($null, $form->{employeepassword}) = split /=/, $_, 2;
-	    $form->{oldemployeepassword} = $form->{employeepassword};
-	    last;
 	  }
 	  $_ = shift @member;
 	} until /^\s/;
@@ -483,7 +486,7 @@ sub prepare_employee {
   $i = 0;
   foreach $ref (@{ $form->{all_payrate} }) {
     $i++;
-    for (qw(rate over)) { $form->{"${_}_$i"} = $ref->{$_} }
+    for (qw(rate above)) { $form->{"${_}_$i"} = $ref->{$_} }
   }
   $form->{payrate_rows} = $i;
 
@@ -532,12 +535,14 @@ sub employee_header {
 <form method=post action=$form->{script}>
 |;
 
-  $form->hide_form(qw(acs payrate_rows wage_rows deduction_rows reference_rows referenceurl status title helpref oldemployeelogin oldemployeepassword company));
+  $form->hide_form(qw(acs payrate_rows wage_rows deduction_rows reference_rows referenceurl status title helpref oldemployeelogin company));
   $form->hide_form(map { "select$_" } qw(paymentmethod payment ap wage deduction acsrole));
   
+  $login = "";
+
   if ($form->{admin}) {
     $sales = ($form->{sales}) ? "checked" : "";
-    $login = "";
+    $pin = ($form->{pin}) ? "checked" : "";
     
     if ($form->{selectacsrole}) {
       $login = qq|
@@ -559,13 +564,16 @@ sub employee_header {
 		<th align=right nowrap>|.$locale->text('Password').qq|</th>
 		<td><input name=employeepassword size=20 value="$form->{employeepassword}"></td>
 	      </tr>
+	      <tr>
+		<th align=right>|.$locale->text('E-mail PIN').qq|</th>
+		<td><input name=pin class=checkbox type=checkbox value=1 $pin></td>
+	      </tr>
 	      <tr>
 		<th align=right>|.$locale->text('Sales').qq|</th>
 		<td><input name=sales class=checkbox type=checkbox value=1 $sales></td>
 	      </tr>
 |;
   } else {
-    $sales = ($form->{sales}) ? "x" : "";
     ($acsrole) = split /--/, $form->{acsrole};
     if ($form->{selectacsrole}) {
       $login = qq|
@@ -575,18 +583,33 @@ sub employee_header {
 	      </tr>
 |;
     }
-    $login .= qq|
+
+    if ($form->{employeelogin}) {
+      $login .= qq|
 	      <tr>
 		<th align=right nowrap>|.$locale->text('Login').qq|</th>
 		<td>$form->{employeelogin}</td>
 	      </tr>
+|;
+    }
+    if ($form->{pin}) {
+      $login .= qq|
 	      <tr>
-		<th align=right>|.$locale->text('Sales').qq|</th>
-		<td>$sales</td>
+		<th align=right nowrap>|.$locale->text('E-mail PIN').qq|</th>
+		<td>x</td>
 	      </tr>
 |;
+    }
+    if ($form->{sales}) {
+      $login .= qq|
+	      <tr>
+		<th align=right>|.$locale->text('Sales').qq|</th>
+		<td>x</td>
+	      </tr>
+|;
+    }
 
-    $form->hide_form(qw(acsrole employeelogin sales employeepassword));
+    $form->hide_form(qw(acsrole employeelogin sales pin employeepassword));
   }
 
   print qq|
@@ -855,7 +878,7 @@ sub employee_header {
     print qq|
 	      <tr>
 		<td><input name="rate_$i" size=10 class="inputright" value=|.$form->format_amount(\%myconfig, $form->{"rate_$i"}, $form->{precision}).qq|></td>
-		<td><input name="over_$i" size=10 class="inputright" value=|.$form->format_amount(\%myconfig, $form->{"over_$i"}).qq|></td>
+		<td><input name="above_$i" size=10 class="inputright" value=|.$form->format_amount(\%myconfig, $form->{"above_$i"}).qq|></td>
 	      </tr>
 |;
   }
@@ -1119,30 +1142,36 @@ sub save_memberfile {
   }
 
   if ($form->{employeelogin}) {
-    $employeelogin = $form->{employeelogin};
-    $employeelogin .= "\@$myconfig{dbname}";  # new format
+    $employeelogin = "$form->{employeelogin}\@$myconfig{dbname}";
     
     # assign values from old entries
-    $oldlogin = $form->{oldemployeelogin};
-    $oldlogin .= "\@$myconfig{dbname}";
+    $oldlogin = "$form->{oldemployeelogin}\@$myconfig{dbname}";
 
     srand( time() ^ ($$ + ($$ << 15)) );
     
     if (@{ $member{$oldlogin} }) {
-      @memberlogin = grep !/password=/, @{ $member{$oldlogin} };
+      @memberlogin = grep !/^(name=|email=|password=|pin=)/, @{ $member{$oldlogin} };
+      ($oldemployeepassword) = grep /^password=/, @{ $member{$oldlogin} };
       pop @memberlogin;
 
-      if ($form->{employeepassword} ne $form->{oldemployeepassword}) {
+      $oldemployeepassword =~ s/password=//;
+      chomp $oldemployeepassword;
+
+      $form->{employeepassword} = $oldemployeepassword if $form->{nochange};
+
+      if ($form->{employeepassword} ne $oldemployeepassword) {
 	if ($form->{employeepassword}) {
 	  $password = crypt $form->{employeepassword}, substr($form->{employeelogin}, 0, 2);
 	  push @memberlogin, "password=$password\n";
 	}
       } else {
-	if ($form->{oldemployeepassword}) {
-	  push @memberlogin, "password=$form->{oldemployeepassword}\n";
+	if ($oldemployeepassword) {
+	  push @memberlogin, "password=$oldemployeepassword\n";
 	}
       }
-      
+
+      for (qw(name email pin)) { push @memberlogin, "$_=$form->{$_}\n" if $form->{$_} }
+
       @{ $member{$employeelogin} } = ();
       
       for (@memberlogin) {
@@ -1150,9 +1179,9 @@ sub save_memberfile {
       }
       
     } else {
-      for (qw(company dateformat dbconnect dbdriver dbname dbhost dboptions dbpasswd dbuser numberformat)) {
-	$m{$_} = $myconfig{$_};
-      }
+      for (qw(company dateformat dbconnect dbdriver dbname dbhost dboptions dbpasswd dbuser numberformat)) { $m{$_} = $myconfig{$_} }
+      for (qw(name email pin)) { $m{$_} = $form->{$_} }
+
       $m{dbpasswd} = pack 'u', $myconfig{dbpasswd};
       chop $m{dbpasswd};
       $m{stylesheet} = 'sql-ledger.css';
@@ -1359,7 +1388,7 @@ sub prepare_payroll {
 
     for $i (1 .. $form->{payrate_rows}) {
       $form->{"rate_$i"} = $form->format_amount(\%myconfig, $form->{"rate_$i"}, $form->{precision});
-      $form->{"over_$i"} = $form->format_amount(\%myconfig, $form->{"over_$i"});
+      $form->{"above_$i"} = $form->format_amount(\%myconfig, $form->{"above_$i"});
     }
     
     $form->{paid} = $form->format_amount(\%myconfig, $form->{paid}, $form->{precision});
@@ -1455,7 +1484,7 @@ sub payroll_header {
       print qq|
 	      <tr>
 		<td></td>
-		<td>$form->{"rate_$i"} > $form->{"over_$i"}</td>
+		<td>$form->{"rate_$i"} > $form->{"above_$i"}</td>
 	      </tr>
 |;
     }
@@ -1811,7 +1840,7 @@ sub update_payroll {
   for $ref (@{ $form->{all_payrate} }) {
     $i++;
     $form->{"rate_$i"} = $form->format_amount(\%myconfig, $ref->{rate}, $form->{precision});
-    $form->{"over_$i"} = $form->format_amount(\%myconfig, $ref->{over});
+    $form->{"above_$i"} = $form->format_amount(\%myconfig, $ref->{above});
   }
   $form->{payrate_rows} = $i;
 
@@ -2207,7 +2236,7 @@ sub payroll_transactions {
   }
   
   # total
-  for (@column_index) { $column_data{$_} = "<td>&nbsp;</td" }
+  for (@column_index) { $column_data{$_} = "<th>&nbsp;</th>" }
 
   $column_data{paid} = "<th align=right>".$form->format_amount(\%myconfig, $form->{"totalpaid"}, $form->{precision}, "&nbsp;")."</th>";
   
@@ -2976,7 +3005,7 @@ sub update_employee {
   $form->{deduction_rows} = $count;
 
 
-  @flds = qw(rate over);
+  @flds = qw(rate above);
   $count = 0;
   @f = ();
   for $i (1 .. $form->{payrate_rows}) {
