@@ -769,7 +769,7 @@ sub form_footer {
 
   $column_data{datepaid} = "<th>".$locale->text('Date')."</th>";
   $column_data{paid} = "<th>".$locale->text('Amount')."</th>";
-  $column_data{exchangerate} = "<th>".$locale->text('Exch')." <font color=red>*</font></th>";
+  $column_data{exchangerate} = "<th>".$locale->text('Exch')."</th>";
   $column_data{AR_paid} = "<th>".$locale->text('Account')."</th>";
   $column_data{source} = "<th>".$locale->text('Source')."</th>";
   $column_data{memo} = "<th>".$locale->text('Memo')."</th>";
@@ -905,8 +905,6 @@ sub form_footer {
 
   for $i (1 .. $form->{paidaccounts}) {
 
-    $form->{"paid_$i"} = $form->parse_amount(\%myconfig, $form->{"paid_$i"});
-
     print "
         <tr>\n";
 
@@ -1191,7 +1189,7 @@ sub update {
 
     if ($form->{rebuildpartsgroup}) {
      ######### pos
-     $form->{lookup} = $locale->text('Main Groups');
+     $form->{lookup} = "";
       for (@{ $form->{all_partsgroup} }) {
 	if ($_->{pos}) {
 	  $form->{lookup} .= "\n$_->{partsgroup}--$_->{translation}--$_->{image}";
